[![Documentation Status](https://readthedocs.org/projects/intlevpy/badge/?version=latest)](https://intlevpy.readthedocs.io/en/latest/)
[![License](https://img.shields.io/badge/License-MIT-brightgreen)](https://github.com/shailendrabhandari/IntLevPy/blob/main/LICENSE)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/intlevpy)](https://pypi.org/project/IntLevPy/)
[![PyPI](https://img.shields.io/pypi/v/intlevpy)](https://pypi.org/project/IntLevPy/)
[![Downloads](https://pepy.tech/badge/intlevpy)](https://pepy.tech/project/intlevpy)
[![GitHub Watchers](https://img.shields.io/github/watchers/shailendrabhandari/IntLevPy?style=social)](https://github.com/shailendrabhandari/IntLevPy/watchers)
[![GitHub Stars](https://img.shields.io/github/stars/shailendrabhandari/IntLevPy?style=social)](https://github.com/shailendrabhandari/IntLevPy/stargazers)


# IntLevPy: Intermittent Lévy Processes Package

IntLevPy is a Python package for simulating and analyzing intermittent and Lévy processes. It provides tools for process simulation, moments calculation, optimization, and classification methods, making it ideal for researchers and practitioners in fields like statistical physics and complex systems.

Overview
---

- **Simulation:** Generate synthetic intermittent and Lévy flight trajectories.
- **Moments Calculation:** Compute theoretical and empirical moments of trajectories.
- **Optimization:** Fit model parameters to empirical data using optimization techniques.
- **Classification:** Differentiate between intermittent and Lévy processes using statistical methods.

For detailed documentation and examples, visit the [IntLevPy Documentation](https://intlevpy.readthedocs.io/en/latest/).

## Installation

Install **IntLevPy** directly from PyPI:

```bash
pip install IntLevPy
```

## Usage

To use **IntLevPy**, import the relevant modules and functions in your Python script or notebook. The package provides functions for simulating processes, computing moments, performing optimizations, and classifying trajectories.


### Applying to emperical Data

**IntLevPy** can be applied to real-life datasets, such as eye-tracking data or financial time series, for classification and analysis using the provided statistical methods.

An example notebook demonstrating the usage of an eye-tracking dataset can be found in the [Example Notebook](https://github.com/shailendrabhandari/IntLevPy/blob/main/intermittent_levy/examples/example_notebook.ipynb).


## Model

![Intermittent Lévy Process Model](https://raw.githubusercontent.com/shailendrabhandari/IntLevPy/main/intermittent_levy/examples/results/model.jpg)

*Figure: Schematic representation of how the IntLevPy package.*

## Contact

For questions or inquiries:

 **Shailendra Bhandari**
  - Email: shailendra.bhandari@oslomet.no


---

**PyPI Package:** [IntLevPy on PyPI](https://pypi.org/project/IntLevPy/)

**Documentation:** [IntLevPy Documentation](https://intlevpy.readthedocs.io/en/latest/)

**License:** This package is licensed under the [MIT License](https://github.com/shailendrabhandari/IntLevPy/blob/main/LICENSE).

---

**Contributors:** For a detailed list of contributors, visit the [Contributors Page](https://intlevpy.readthedocs.io/en/latest/authors.html#contributors).

--- 